%
% This demo implements the method described in:
%
% "A Game-Theoretic Approach to Deformable Shape Matching"
% Rodola, Bronstein, Albarelli, Bergamasco, Torsello
% Proc. CVPR 2012
%
% Please reference the paper above if you use this in your research.
%
%%
clear all
close all
clc

addpath('./tools/')
addpath('./method/')

options = struct;

% safe to ignore this bunch of parameters
options.tmp_dir           = './tmp/';
options.min_boundary_dist = 0;
options.descr_dist_thresh = Inf;
options.densify           = false; % not implemented in this demo
options.densify_amount    = 0.8;

% Interesting parameters:

options.n_samples         = 1e3;   % farthest point sampling

options.min_matches_dist  = 1/7;   % min. distance between matches 
                                   % (percentage of shape diameter)
                                   
options.descr_knn         = 10;    % no. of candidate matches per point

options.rigid             = false; % TRUE if you deal with rigid shapes

options.multi_start       = false; % setting this to TRUE will lead to a
                                   % better, but usually sparser local
                                   % optimum

%% Load the shapes and compute some pointwise descriptor

M = load_off('./shapes/michael0.off');
M.name = 'michael0';
[M.evecs, M.evals, M.S, ~] = calc_LB(M, 100);
M.desc = calc_WKS(M, 100, 6.0); % you can also use a different descriptor

N = load_off('./shapes/michael1.off');
N.name = 'michael1';
[N.evecs, N.evals, N.S, ~] = calc_LB(N, 100);
N.desc = calc_WKS(N, 100, 6.0);

%% Run L1-regularized QAP optimization (game-theoretic matching)

% NOTE: the first execution will be slow due to distance calculation
result = match_qap_l1(M, N, options);

figure
subplot(1,2,1), plot_mesh(N), shading interp, hold on; axis off
subplot(1,2,2), plot_mesh(M), shading interp, hold on; axis off
for i=1:size(result.matches,1)
    color = rand(1,3);
    subplot(1,2,1), plot_cloud(N, result.matches(i,1), color)
    subplot(1,2,2), plot_cloud(M, result.matches(i,2), color)
end
